@@ -1,3 +1,3 @@
-from ._core import load, to_datarr, to_datset
+from ._core import load
 
 from ._accessors import _nxrDataArray, _nxrDataset
